starcluster.commands

Package starcluster :: Package commands |
[hide private]
[frames] | no frames]

# Package commands

source code

Submodules | [hide private]
starcluster.commands.addnode starcluster.commands.base starcluster.commands.completers starcluster.commands.createkey starcluster.commands.createvolume starcluster.commands.downloadimage starcluster.commands.ebsimage starcluster.commands.help starcluster.commands.listbuckets starcluster.commands.listclusters starcluster.commands.listimages starcluster.commands.listinstances starcluster.commands.listkeypairs starcluster.commands.listpublic starcluster.commands.listregions starcluster.commands.listspots starcluster.commands.listvolumes starcluster.commands.listzones starcluster.commands.loadbalance starcluster.commands.removeimage starcluster.commands.removekey starcluster.commands.removenode starcluster.commands.removevolume starcluster.commands.resizevolume starcluster.commands.restart starcluster.commands.runplugin starcluster.commands.s3image starcluster.commands.shell starcluster.commands.showbucket starcluster.commands.showconsole starcluster.commands.showimage starcluster.commands.spothistory starcluster.commands.sshinstance starcluster.commands.sshmaster starcluster.commands.sshnode starcluster.commands.start starcluster.commands.stop starcluster.commands.terminate

Variables | [hide private]
| all_cmds = `[CmdStart(), CmdStop(), CmdTerminate(), CmdRestart(`...``
| __package__ = ``'``starcluster.commands``'``

Variables Details | [hide private]

  ### all_cmds Value:
      [CmdStart(), CmdStop(), CmdTerminate(), CmdRestart(), CmdListClusters(
      ), CmdSshMaster(), CmdSshNode(), CmdAddNode(), CmdRemoveNode(), CmdLoa
      dBalance(), CmdSshInstance(), CmdListInstances(), CmdListSpots(), CmdL
      istImages(), CmdListPublic(), CmdListKeyPairs(), CmdCreateKey(), CmdRe
      moveKey(), CmdS3Image(), CmdEbsImage(), CmdShowImage(), CmdDownloadIma
      ge(), CmdRemoveImage(), CmdCreateVolume(), CmdListVolumes(), CmdResize
      Volume(), CmdRemoveVolume(), CmdSpotHistory(), CmdShowConsole(), CmdLi
      stRegions(), CmdListZones(), CmdListBuckets(), CmdShowBucket(), CmdRun
      ...